==> goshawk-0.0.1.3.tar.gz: goshawk-0.0.1.3/README.md <==
# goshawk

[![Release](https://img.shields.io/github/v/release/ebrassell/goshawk)](https://img.shields.io/github/v/release/ebrassell/goshawk)
[![Build status](https://img.shields.io/github/actions/workflow/status/ebrassell/goshawk/main.yml?branch=main)](https://github.com/ebrassell/goshawk/actions/workflows/main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/ebrassell/goshawk/branch/main/graph/badge.svg)](https://codecov.io/gh/ebrassell/goshawk)
[![Commit activity](https://img.shields.io/github/commit-activity/m/ebrassell/goshawk)](https://img.shields.io/github/commit-activity/m/ebrassell/goshawk)
[![License](https://img.shields.io/github/license/ebrassell/goshawk)](https://img.shields.io/github/license/ebrassell/goshawk)

A tool for managing SQL Models

- **Github repository**: <https://github.com/ebrassell/goshawk/>
- **Documentation** <https://ebrassell.github.io/goshawk/>

## Getting started with your project

First, create a repository on GitHub with the same name as this project, and then run the following commands:

```bash
git init -b main
git add .
git commit -m "init commit"
git remote add origin git@github.com:ebrassell/goshawk.git
git push -u origin main
```

Finally, install the environment and the pre-commit hooks with

```bash
make install
```

You are now ready to start development on your project!
The CI/CD pipeline will be triggered when you open a pull request, merge to main, or when you create a new release.

To finalize the set-up for publishing to PyPi or Artifactory, see [here](https://fpgmaas.github.io/cookiecutter-poetry/features/publishing/#set-up-for-pypi).
For activating the automatic documentation with MkDocs, see [here](https://fpgmaas.github.io/cookiecutter-poetry/features/mkdocs/#enabling-the-documentation-on-github).
To enable the code coverage reports, see [here](https://fpgmaas.github.io/cookiecutter-poetry/features/codecov/).

## Releasing a new version

- Create an API Token on [Pypi](https://pypi.org/).
- Add the API Token to your projects secrets with the name `PYPI_TOKEN` by visiting [this page](https://github.com/ebrassell/goshawk/settings/secrets/actions/new).
- Create a [new release](https://github.com/ebrassell/goshawk/releases/new) on Github.
- Create a new tag in the form `*.*.*`.

For more details, see [here](https://fpgmaas.github.io/cookiecutter-poetry/features/cicd/#how-to-trigger-a-release).

---

Repository initiated with [fpgmaas/cookiecutter-poetry](https://github.com/fpgmaas/cookiecutter-poetry).

==> goshawk-0.0.1.4rc0.tar.gz: goshawk-0.0.1.4rc0/README.md <==
# goshawk

[![Release](https://img.shields.io/github/v/release/ebrassell/goshawk)](https://img.shields.io/github/v/release/ebrassell/goshawk)
[![Build status](https://img.shields.io/github/actions/workflow/status/ebrassell/goshawk/main.yml?branch=main)](https://github.com/ebrassell/goshawk/actions/workflows/main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/ebrassell/goshawk/branch/main/graph/badge.svg)](https://codecov.io/gh/ebrassell/goshawk)
[![Commit activity](https://img.shields.io/github/commit-activity/m/ebrassell/goshawk)](https://img.shields.io/github/commit-activity/m/ebrassell/goshawk)
[![License](https://img.shields.io/github/license/ebrassell/goshawk)](https://img.shields.io/github/license/ebrassell/goshawk)

SQL Model Management for Humans

- **Github repository**: <https://github.com/ebrassell/goshawk/>
- **Documentation** <https://ebrassell.github.io/goshawk/>

## Getting started with your Goshawk

Install goshawk into a virtual environment using pip (we recommend using pipx) :

```bash
pip install gohawk
```

Set MODELS_PATH env var to the folder containing your models.

```bash
Project Name
`-- models <-set MODELS_PATH to the path to this folder
     -- mydatabase
         -- schema_1
             -- model_1a.sql
             -- model_1b.sql
         -- schema_2
             -- model_2a.sql
             -- model_2b.sql
```

```bash
export MODELS_PATH=models
```

You are now ready to start development on your project!
The CI/CD pipeline will be triggered when you open a pull request, merge to main, or when you create a new release.

To finalize the set-up for publishing to PyPi or Artifactory, see [here](https://fpgmaas.github.io/cookiecutter-poetry/features/publishing/#set-up-for-pypi).
For activating the automatic documentation with MkDocs, see [here](https://fpgmaas.github.io/cookiecutter-poetry/features/mkdocs/#enabling-the-documentation-on-github).
To enable the code coverage reports, see [here](https://fpgmaas.github.io/cookiecutter-poetry/features/codecov/).

## Releasing a new version

- Create an API Token on [Pypi](https://pypi.org/).
- Add the API Token to your projects secrets with the name `PYPI_TOKEN` by visiting [this page](https://github.com/ebrassell/goshawk/settings/secrets/actions/new).
- Create a [new release](https://github.com/ebrassell/goshawk/releases/new) on Github.
- Create a new tag in the form `*.*.*`.

For more details, see [here](https://fpgmaas.github.io/cookiecutter-poetry/features/cicd/#how-to-trigger-a-release).

---

Repository initiated with [fpgmaas/cookiecutter-poetry](https://github.com/fpgmaas/cookiecutter-poetry).
